@@ -5,9 +5,10 @@ import allure
 from .utils.handle_loguru import log
 from time import strftime
 
-case_idx = 1
+
 
 class Exec:
+    case_idx = 1
     def __init__(self,data):
         global case_idx
         self.data = data
@@ -17,8 +18,8 @@ class Exec:
             elif self.data[0]['browser'] == 'firefox':
                 self.driver = webdriver.Firefox()
         self.driver.implicitly_wait(10)
-        if not os.path.isdir(f'screenshot/case{case_idx}'):
-            os.makedirs(f'screenshot/case{case_idx}')
+        if not os.path.isdir(f'screenshot/case{Exec.case_idx}'):
+            os.makedirs(f'screenshot/case{Exec.case_idx}')
 
 
 
@@ -93,12 +94,12 @@ class Exec:
                             if isinstance(result,list):
                                 log.info(f'步骤{step}:{step_text}')
                                 log.info(f'期望值{assert_data[0]},实际值{result}')
-                                case_idx += 1
+                                Exec.case_idx += 1
                                 assert assert_data[0] in result
                             else:
                                 log.info(f'步骤{step}:{step_text}')
                                 log.info(f'期望值{assert_data[0]},实际值{result}')
-                                case_idx += 1
+                                Exec.case_idx += 1
                                 assert assert_data[0] == result
                         except Exception as error:
                             log.info(f'步骤{step}:{step_text}')
@@ -108,7 +109,7 @@ class Exec:
                             with open(file_name, 'rb') as f:
                                 file = f.read()
                             allure.attach(file, attachment_type=allure.attachment_type.PNG)
-                            case_idx += 1
+                            Exec.case_idx += 1
                             raise error
                     else:
                         log.info(f'没有找到变量{assert_data[-1]}')
